//
//  AppController.m
//  CocoaShaders
//
//  Created by Guy English on 03/03/07.
//  Copyright 2007 __MyCompanyName__. All rights reserved.
//

#import "AppController.h"

#import "KBShader.h"
#import "ShaderView.h"

@interface AppController ( Private )

- (void) setupShaders;

@end

@implementation AppController

- (void) applicationDidFinishLaunching: (NSNotification*) note
{
	[self setupShaders];
	
	[_shaderView setShader: [KBShader shaderNamed: @"AppIconOnConditionalBackground"]];
}

@end

@implementation AppController ( Private )

- (void) setupShaders
{
	// make a shader that will fill it's area with red
	KBShader *redShader = [KBShader solidColorShaderWithColor: [NSColor redColor]];
	
	// make a shader that will fill it's area with blue
	KBShader *blueShader = [KBShader solidColorShaderWithColor: [NSColor blueColor]];
	
	// make a shader that will draw an image, the application icon in this case
	KBShader *appIconShader = [KBShader imageShaderWithImage: [NSApp applicationIconImage]];
	
	// make a shader that will translate the icon right then rotate
	NSAffineTransform *transform = [NSAffineTransform transform];
	[transform translateXBy: 128 yBy: 0];
	[transform rotateByDegrees: 33];
	KBShader *transformShader = [KBShader affineTransformShaderWithAffineTransform: transform shader: appIconShader];
	
	// make a shader that will conditionally draw either red or blue depending on the value of the object we're asked to draw
	NSPredicate *backgroundCondition = [NSPredicate predicateWithFormat: @"value == YES"];
	KBShader *backgroundShader = [KBShader conditionalShaderWithPredicate: backgroundCondition
																 ifShader: redShader
															   elseShader: blueShader];
	
	// not really needed - foreground is just one object (the app icon transformed) but we may as well do it this way so it reads better
	KBShader *foregroundShader = [KBShader shaderListWithShaders: [NSArray arrayWithObject: transformShader]];
	
	// make a shader list that will first draw the background then the foreground
	KBShader *appIconOnBackgroundShader = [KBShader shaderListWithShaders: [NSArray arrayWithObjects: backgroundShader, foregroundShader, nil]];
	
	// make a shader that clips the whole thing
	KBShader *clipShader = [KBShader clipShaderWithClipPath: [NSBezierPath bezierPathWithOvalInRect: [_shaderView bounds]]
													 shader: appIconOnBackgroundShader];
	
	// set it's name so we can use it by name later
	// setting a name for a shader means it'll be available until the app quits or you set it's name to nil.
	[clipShader setName: @"AppIconOnConditionalBackground"];
}

@end
