//
//  KBShader.h
//  CocoaShaders
//
//  Created by Guy English on 03/03/07.
//  Copyright 2007 __MyCompanyName__. All rights reserved.
//

#import <Cocoa/Cocoa.h>

@interface KBShader : NSObject <NSCoding>
{
}

- (void) drawInRect: (NSRect) rect input: (id) input;

@end

@interface KBConditionalShader : KBShader <NSCoding>
{
	NSPredicate *_predicate;
	KBShader    *_ifShader;
	KBShader    *_elseShader;
}

- (id) initWithPredicate: (NSPredicate*) predicate ifShader: (KBShader*) shader elseShader: (KBShader*) shader;

@end

@interface KBShaderList : KBShader <NSCoding>
{
	NSArray *_shaders;
}

- (id) initWithShaders: (NSArray*) shaders;

@end

//------------------

@interface KBClipShader : KBShader <NSCoding>
{
	NSBezierPath *_clipPath;
	KBShader     *_shader;
}

- (id) initWithClipPath: (NSBezierPath*) color shader: (KBShader*) shader;

@end

@interface KBAffineTransformShader : KBShader <NSCoding>
{
	NSAffineTransform *_transform;
	KBShader          *_shader;
}

- (id) initWithAffineTransform: (NSAffineTransform*) transform shader: (KBShader*) shader;

@end

@interface KBSolidColorShader : KBShader <NSCoding>
{
	NSColor *_color;
}

- (id) initWithColor: (NSColor*) color;

@end

@interface KBImageShader : KBShader <NSCoding>
{
	NSImage					*_image;
	NSRect					 _srcRect;
	NSCompositingOperation	 _operation;
	float					 _fraction;
	float                    _scale;
}

- (id) initWithImage: (NSImage*) image sourceRect: (NSRect) srcRect operation: (NSCompositingOperation) operation fraction: (float) fraction scale: (float) scale;
- (id) initWithImage: (NSImage*) image;

@end

@interface KBShader ( KBShaderCreation )

+ (KBShader*) conditionalShaderWithPredicate: (NSPredicate*) predicate ifShader: (KBShader*) ifShader elseShader: (KBShader*) elseShader;
+ (KBShader*) shaderListWithShaders: (NSArray*) shaders;
+ (KBShader*) clipShaderWithClipPath: (NSBezierPath*) path shader: (KBShader*) shader;
+ (KBShader*) affineTransformShaderWithAffineTransform: (NSAffineTransform*) transform shader: (KBShader*) shader;
+ (KBShader*) imageShaderWithImage: (NSImage*) image;
+ (KBShader*) solidColorShaderWithColor: (NSColor*) color;

@end

@interface KBShader ( KBShaderNaming )

+ (KBShader*) shaderNamed: (NSString*) name;
+ (void) setName: (NSString*) name forShader: (KBShader*) shader;

- (void) setName: (NSString*) name;
- (NSString*) name;

@end

